aboutsummaryrefslogtreecommitdiff
path: root/Minecraft.World/Painting.cpp
diff options
context:
space:
mode:
authorvoid_17 <heroerror3@gmail.com>2026-03-02 15:58:20 +0700
committervoid_17 <heroerror3@gmail.com>2026-03-02 15:58:20 +0700
commit7074f35e4ba831e358117842b99ee35b87f85ae5 (patch)
tree7d440d23473196af3056bf2ff4c59d9e740a06f5 /Minecraft.World/Painting.cpp
parentd63f79325f85e014361eb8cf1e41eaebedb1ae71 (diff)
shared_ptr -> std::shared_ptr
This is one of the first commits in a plan to remove all `using namespace std;` lines in the entire codebase as it is considered anti-pattern today.
Diffstat (limited to 'Minecraft.World/Painting.cpp')
-rw-r--r--Minecraft.World/Painting.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/Minecraft.World/Painting.cpp b/Minecraft.World/Painting.cpp
index 0d8f35fe..bc4eef38 100644
--- a/Minecraft.World/Painting.cpp
+++ b/Minecraft.World/Painting.cpp
@@ -73,7 +73,7 @@ Painting::Painting(Level *level, int xTile, int yTile, int zTile, int dir) : Han
// 4J Stu - If you use this ctor, then you need to call the PaintingPostConstructor
}
// 4J Stu - Added this so that we can use some shared_ptr functions that were needed in the ctor
void Painting::PaintingPostConstructor(int dir)
{
vector<Motive *> *survivableMotives = new vector<Motive *>();
@@ -132,17 +132,17 @@ void Painting::readAdditionalSaveData(CompoundTag *tag)
HangingEntity::readAdditionalSaveData(tag);
}
-int Painting::getWidth()
+int Painting::getWidth()
{
return motive->w;
}
-int Painting::getHeight()
+int Painting::getHeight()
{
return motive->h;
}
-void Painting::dropItem()
+void Painting::dropItem()
{
- spawnAtLocation(shared_ptr<ItemInstance>(new ItemInstance(Item::painting)), 0.0f);
+ spawnAtLocation(std::shared_ptr<ItemInstance>(new ItemInstance(Item::painting)), 0.0f);
} \ No newline at end of file
@@ -73,7 +73,7 @@ Painting::Painting(Level *level, int xTile, int yTile, int zTile, int dir) : Han
// 4J Stu - If you use this ctor, then you need to call the PaintingPostConstructor
}
-// 4J Stu - Added this so that we can use some shared_ptr functions that were needed in the ctor
+// 4J Stu - Added this so that we can use some std::shared_ptr functions that were needed in the ctor
void Painting::PaintingPostConstructor(int dir)
{